Error types for Calimero client operations
This module defines the main error type for client operations.
Enums
- Client
Error - Main error type for Calimero client operations
Error types for Calimero client operations
This module defines the main error type for client operations.