pub struct Client<A, S>{ /* private fields */ }Expand description
Generic API client that can work with any authenticator and storage implementation
Implementations
Sourceimpl<A, S> Client<A, S>
impl<A, S> Client<A, S>
pub fn new(connection: ConnectionInfo<A, S>) -> Result<Self>
pub fn api_url(&self) -> &Url
pub async fn get_application( &self, app_id: &ApplicationId, ) -> Result<GetApplicationResponse>
pub async fn install_dev_application( &self, request: InstallDevApplicationRequest, ) -> Result<InstallApplicationResponse>
pub async fn install_application( &self, request: InstallApplicationRequest, ) -> Result<InstallApplicationResponse>
pub async fn list_applications(&self) -> Result<ListApplicationsResponse>
pub async fn uninstall_application( &self, app_id: &ApplicationId, ) -> Result<UninstallApplicationResponse>
pub async fn delete_blob(&self, blob_id: &BlobId) -> Result<BlobDeleteResponse>
pub async fn list_blobs(&self) -> Result<BlobListResponse>
pub async fn get_blob_info(&self, blob_id: &BlobId) -> Result<BlobInfoResponse>
pub async fn upload_blob( &self, data: Vec<u8>, context_id: Option<&ContextId>, ) -> Result<BlobInfo>
pub async fn download_blob( &self, blob_id: &BlobId, context_id: Option<&ContextId>, ) -> Result<Vec<u8>>
pub async fn generate_context_identity( &self, ) -> Result<GenerateContextIdentityResponse>
pub async fn get_peers_count(&self) -> Result<GetPeersCountResponse>
pub async fn execute_jsonrpc<P>(&self, request: Request<P>) -> Result<Response>where
P: Serialize,
pub async fn grant_permissions( &self, context_id: &ContextId, request: Vec<(PublicKey, Capability)>, ) -> Result<GrantPermissionResponse>
pub async fn revoke_permissions( &self, context_id: &ContextId, request: Vec<(PublicKey, Capability)>, ) -> Result<RevokePermissionResponse>
pub async fn invite_to_context( &self, request: InviteToContextRequest, ) -> Result<InviteToContextResponse>
pub async fn invite_to_context_by_open_invitation( &self, request: InviteToContextOpenInvitationRequest, ) -> Result<InviteToContextOpenInvitationResponse>
Sourcepub async fn invite_specialized_node(
&self,
request: InviteSpecializedNodeRequest,
) -> Result<InviteSpecializedNodeResponse>
pub async fn invite_specialized_node( &self, request: InviteSpecializedNodeRequest, ) -> Result<InviteSpecializedNodeResponse>
Invite specialized nodes (e.g., read-only TEE nodes) to join a context.
This broadcasts a specialized node discovery request to the global invite topic. Specialized nodes listening will respond with verification and receive invitations.
pub async fn update_context_application( &self, context_id: &ContextId, request: UpdateContextApplicationRequest, ) -> Result<UpdateContextApplicationResponse>
pub async fn get_proposal( &self, context_id: &ContextId, proposal_id: &Hash, ) -> Result<GetProposalResponse>
pub async fn get_proposal_approvers( &self, context_id: &ContextId, proposal_id: &Hash, ) -> Result<GetProposalApproversResponse>
pub async fn create_and_approve_proposal( &self, context_id: &ContextId, request: CreateAndApproveProposalRequest, ) -> Result<CreateAndApproveProposalResponse>
pub async fn approve_proposal( &self, context_id: &ContextId, request: ApproveProposalRequest, ) -> Result<ApproveProposalResponse>
pub async fn list_proposals( &self, context_id: &ContextId, args: Value, ) -> Result<GetProposalsResponse>
pub async fn get_context( &self, context_id: &ContextId, ) -> Result<GetContextResponse>
pub async fn list_contexts(&self) -> Result<GetContextsResponse>
pub async fn create_context( &self, request: CreateContextRequest, ) -> Result<CreateContextResponse>
pub async fn delete_context( &self, context_id: &ContextId, ) -> Result<DeleteContextResponse>
pub async fn join_context( &self, request: JoinContextRequest, ) -> Result<JoinContextResponse>
pub async fn join_context_by_open_invitation( &self, request: JoinContextByOpenInvitationRequest, ) -> Result<JoinContextResponse>
pub async fn get_context_storage( &self, context_id: &ContextId, ) -> Result<GetContextStorageResponse>
pub async fn get_context_identities( &self, context_id: &ContextId, owned: bool, ) -> Result<GetContextIdentitiesResponse>
pub async fn get_context_client_keys( &self, context_id: &ContextId, ) -> Result<GetContextClientKeysResponse>
pub async fn sync_context( &self, context_id: &ContextId, ) -> Result<SyncContextResponse>
Sourcepub async fn sync_all_contexts(&self) -> Result<SyncContextResponse>
pub async fn sync_all_contexts(&self) -> Result<SyncContextResponse>
Sync all contexts (legacy method for backward compatibility)
Sourcepub async fn create_context_identity_alias(
&self,
context_id: &ContextId,
request: CreateAliasRequest<PublicKey>,
) -> Result<CreateAliasResponse>
pub async fn create_context_identity_alias( &self, context_id: &ContextId, request: CreateAliasRequest<PublicKey>, ) -> Result<CreateAliasResponse>
Create context identity alias (legacy method for backward compatibility)
Sourcepub async fn create_alias_generic<T>(
&self,
alias: Alias<T>,
scope: Option<T::Scope>,
value: T,
) -> Result<CreateAliasResponse>
pub async fn create_alias_generic<T>( &self, alias: Alias<T>, scope: Option<T::Scope>, value: T, ) -> Result<CreateAliasResponse>
Create alias generic (legacy method for backward compatibility)
pub async fn create_alias<T>( &self, alias: Alias<T>, value: T, scope: Option<T::Scope>, ) -> Result<CreateAliasResponse>
pub async fn delete_alias<T>(
&self,
alias: Alias<T>,
scope: Option<T::Scope>,
) -> Result<DeleteAliasResponse>where
T: UrlFragment,
pub async fn list_aliases<T>( &self, scope: Option<T::Scope>, ) -> Result<ListAliasesResponse<T>>
pub async fn lookup_alias<T>(
&self,
alias: Alias<T>,
scope: Option<T::Scope>,
) -> Result<LookupAliasResponse<T>>where
T: UrlFragment + DeserializeOwned,
pub async fn resolve_alias<T>( &self, alias: Alias<T>, scope: Option<T::Scope>, ) -> Result<ResolveResponse<T>>
pub async fn list_packages(&self) -> Result<ListPackagesResponse>
pub async fn list_versions(&self, package: &str) -> Result<ListVersionsResponse>
pub async fn get_latest_version( &self, package: &str, ) -> Result<GetLatestVersionResponse>